Struct BinMulOutput
pub struct BinMulOutput<F> {
pub eval_point: Vec<F>,
pub a_lo_evals: [F; 64],
pub a_hi_evals: [F; 64],
pub b_lo_evals: [F; 64],
pub b_hi_evals: [F; 64],
pub c_lo_evals: [F; 64],
pub c_hi_evals: [F; 64],
}Expand description
Output of the BinMul reduction.
The reduction proves the constraint $\widetilde{A}(x) \cdot \widetilde{B}(x) =
\widetilde{C}(x)$ for every $x$ on the boolean hypercube $\mathbb{B}\ell$, where each
$\mathbb{F}{2^{128}}$ element is carried by a (lo, hi) pair of 64-bit words. It reduces the
constraint to per-bit evaluation claims on the six word columns at a common evaluation point
eval_point ($r_x \in K^\ell$).
Each *_evals array holds Word::BITS per-bit evaluation claims $\widetilde{z}(r_x, i)$ for
$i \in {0, \ldots, 63}$.
Fields
eval_point: Vec<F>a_lo_evals: [F; 64]a_hi_evals: [F; 64]b_lo_evals: [F; 64]b_hi_evals: [F; 64]c_lo_evals: [F; 64]c_hi_evals: [F; 64]Implementations
impl<F> BinMulOutput<F>
impl<F> BinMulOutput<F>
pub fn operand_claims(&self) -> OperandClaims<'_, F>
pub fn operand_claims(&self) -> OperandClaims<'_, F>
The operand claims, in the shift operand order [a_lo, a_hi, b_lo, b_hi, c_lo, c_hi].